Skip to contents

Convenience function to extract just the text content from a chat result, useful for programmatic use or piping.

Usage

chat_text(x)

Arguments

x

A cassidy_chat or cassidy_response object.

Value

Character. The text content of the response.

Examples

if (FALSE) { # \dontrun{
result <- cassidy_chat("What is 2+2?")
text <- chat_text(result)
cat(text)
} # }