Convenience function to extract just the text content from a chat result, useful for programmatic use or piping.
See also
Other chat-functions:
cassidy_chat(),
cassidy_continue(),
cassidy_session(),
cassidy_write_code(),
cassidy_write_file(),
chat()
Examples
if (FALSE) { # \dontrun{
result <- cassidy_chat("What is 2+2?")
text <- chat_text(result)
cat(text)
} # }